/**
 * CountDownTimer Component
 */

import React, { useState, useEffect, useRef, forwardRef, useImperativeHandle } from 'react';
import { Text, View } from 'react-native';
const CountDownTimer = /*#__PURE__*/forwardRef((props, ref) => {
  const [timeStamp, setTimeStamp] = useState(props.timestamp ?? 0);
  const delay = props.delay ?? 1000;
  const [sendOnce, setSendOnce] = useState(true);
  const TimePlaceholder = props.format ? ['DHMS'].includes(props.format) ? '00:00:00:00' : ['DHM', 'HMS'].includes(props.format) ? '00:00:00' : ['MS', 'HM', 'DH'].includes(props.format) ? '00:00' : '00:00:00' : '00:00:00';
  const [finalDisplayTime, setFinalDisplayTime] = useState(TimePlaceholder);
  useInterval(() => {
    if (timeStamp > 0) {
      setTimeStamp(timeStamp - 1);
      if (props.timerOnProgress) {
        props.timerOnProgress(timeStamp - 1);
      }
    } else if (sendOnce) {
      if (props.timerCallback) {
        props.timerCallback(true);
      } else {
        console.log('Pass a callback function that will trigger once timer runs out....');
      }
      setSendOnce(false);
    }
    let delta = timeStamp;
    const Days = Math.floor(delta / 86400);
    delta %= 86400;
    const Hours = Math.floor(delta / 3600);
    delta %= 3600;
    const Minutes = Math.floor(delta / 60);
    const Seconds = delta % 60;
    const totalHours = Days * 24 + Hours;
    const totalMinutes = totalHours * 60 + Minutes;
    const hr = Hours < 10 ? `0${Hours}` : Hours;
    const min = Minutes < 10 ? `0${Minutes}` : Minutes;
    const sec = Seconds < 10 ? `0${Seconds}` : Seconds;
    let displayTime = '';
    if (props.format) {
      if (props.format === 'DHMS') {
        displayTime = `${props.showDoubleZero && Days === 0 ? '00' : Days < 10 ? `0${Days}` : Days}:${hr}:${min}:${sec}`;
      } else if (props.format === 'HMS') {
        displayTime = `${props.showDoubleZero && totalHours === 0 ? '00' : totalHours < 10 ? `0${totalHours}` : totalHours}:${min}:${sec}`;
      } else if (props.format === 'MS') {
        displayTime = `${totalMinutes}:${sec}`;
      } else if (props.format === 'HM') {
        displayTime = `${props.showDoubleZero && totalHours === 0 ? '00' : totalHours < 10 ? `0${totalHours}` : totalHours}:${min}`;
      } else if (props.format === 'DHM') {
        displayTime = `${Days}:${hr}:${min}`;
      } else if (props.format === 'DH') {
        displayTime = `${Days}:${hr}`;
      }
    } else {
      if (Days !== 0) {
        displayTime = `${Days}:${hr}:${min}:${sec}`;
      } else if (Hours !== 0) {
        displayTime = `${hr}:${min}:${sec}`;
      } else if (Minutes !== 0) {
        displayTime = `${min}:${sec}`;
      } else if (Seconds !== 0) {
        displayTime = `${min}:${sec}`;
      }
    }
    setFinalDisplayTime(displayTime);
  }, delay);
  useImperativeHandle(ref, () => ({
    resetTimer: () => {
      setTimeStamp(props.timestamp ?? 0);
      setSendOnce(true);
    }
  }));
  return /*#__PURE__*/React.createElement(View, {
    style: props.containerStyle
  }, /*#__PURE__*/React.createElement(Text, {
    style: props.textStyle
  }, finalDisplayTime));
});
function useInterval(callback, delay) {
  const savedCallback = useRef();
  useEffect(() => {
    savedCallback.current = callback;
  }, [callback]);
  useEffect(() => {
    function tick() {
      var _savedCallback$curren;
      (_savedCallback$curren = savedCallback.current) === null || _savedCallback$curren === void 0 || _savedCallback$curren.call(savedCallback);
    }
    if (delay !== null) {
      const id = setInterval(tick, delay);
      return () => clearInterval(id);
    }
  }, [delay]);
}
export default CountDownTimer;
//# sourceMappingURL=index.js.map